@@ -1,7 +1,9 @@
 import os
+import re
 
 from pipenv.project import Project
 from pipenv.utils.internet import is_valid_url
+from pipenv.vendor import click
 from pipenv.vendor.click import (
     BadArgumentUsage,
     BadParameter,
@@ -63,8 +65,6 @@ class State:
         self.quiet = False
         self.pypi_mirror = None
         self.python = None
-        self.two = None
-        self.three = None
         self.site_packages = None
         self.clear = False
         self.system = False
@@ -81,19 +81,18 @@ class InstallState:
         self.keep_outdated = False
         self.skip_lock = False
         self.ignore_pipfile = False
-        self.sequential = False
         self.code = False
         self.requirementstxt = None
         self.deploy = False
         self.packages = []
         self.editables = []
+        self.extra_pip_args = []
+        self.categories = []
 
 
 class LockOptions:
     def __init__(self):
         self.dev_only = False
-        self.emit_requirements = False
-        self.emit_requirements_header = False
 
 
 pass_state = make_pass_decorator(State, ensure=True)
@@ -128,29 +127,11 @@ def editable_option(f):
         expose_value=False,
         multiple=True,
         callback=callback,
-        type=click_types.STRING,
+        type=click_types.Path(file_okay=False),
         help="An editable Python package URL or path, often to a VCS repository.",
     )(f)
 
 
-def sequential_option(f):
-    def callback(ctx, param, value):
-        state = ctx.ensure_object(State)
-        state.installstate.sequential = value
-        return value
-
-    return option(
-        "--sequential",
-        is_flag=True,
-        default=False,
-        expose_value=False,
-        help="Install dependencies one-at-a-time, instead of concurrently.",
-        callback=callback,
-        type=click_types.BOOL,
-        show_envvar=True,
-    )(f)
-
-
 def skip_lock_option(f):
     def callback(ctx, param, value):
         state = ctx.ensure_object(State)
@@ -174,6 +155,15 @@ def keep_outdated_option(f):
     def callback(ctx, param, value):
         state = ctx.ensure_object(State)
         state.installstate.keep_outdated = value
+        if value:
+            click.secho(
+                "The flag --keep-outdated has been deprecated for removal."
+                "The flag does not respect package resolver results and leads to inconsistent lock files.  "
+                "Please pin relevant requirements in your Pipfile and discontinue use of this flag.",
+                fg="yellow",
+                bold=True,
+                err=True,
+            )
         return value
 
     return option(
@@ -242,6 +232,24 @@ def _dev_option(f, help_text):
     )(f)
 
 
+def categories_option(f):
+    def callback(ctx, param, value):
+        state = ctx.ensure_object(State)
+        if value:
+            for opt in re.split(r", *| ", value):
+                state.installstate.categories.append(opt)
+        return value
+
+    return option(
+        "--categories",
+        nargs=1,
+        required=False,
+        callback=callback,
+        expose_value=True,
+        type=click_types.STRING,
+    )(f)
+
+
 def install_dev_option(f):
     return _dev_option(f, "Install both develop and default packages")
 
@@ -283,25 +291,26 @@ def package_arg(f):
         "packages",
         nargs=-1,
         callback=callback,
-        expose_value=False,
+        expose_value=True,
         type=click_types.STRING,
     )(f)
 
 
-def three_option(f):
+def extra_pip_args(f):
     def callback(ctx, param, value):
         state = ctx.ensure_object(State)
-        if value is not None:
-            state.three = value
+        if value:
+            for opt in value.split(" "):
+                state.installstate.extra_pip_args.append(opt)
         return value
 
     return option(
-        "--three",
-        is_flag=True,
-        default=None,
-        help="Use Python 3 when creating virtualenv.",
+        "--extra-pip-args",
+        nargs=1,
+        required=False,
         callback=callback,
-        expose_value=False,
+        expose_value=True,
+        type=click_types.STRING,
     )(f)
 
 
@@ -456,42 +465,7 @@ def requirementstxt_option(f):
         expose_value=False,
         help="Import a requirements.txt file.",
         callback=callback,
-        type=click_types.STRING,
-    )(f)
-
-
-def emit_requirements_flag(f):
-    def callback(ctx, param, value):
-        state = ctx.ensure_object(State)
-        if value:
-            state.lockoptions.emit_requirements = value
-        return value
-
-    return option(
-        "--requirements",
-        "-r",
-        default=False,
-        is_flag=True,
-        expose_value=False,
-        help="Generate output in requirements.txt format.",
-        callback=callback,
-    )(f)
-
-
-def emit_requirements_header_flag(f):
-    def callback(ctx, param, value):
-        state = ctx.ensure_object(State)
-        if value:
-            state.lockoptions.emit_requirements_header = value
-        return value
-
-    return option(
-        "--header/--no-header",
-        default=True,
-        is_flag=True,
-        expose_value=False,
-        help="Add header to generated requirements",
-        callback=callback,
+        type=click_types.Path(dir_okay=False),
     )(f)
 
 
@@ -532,15 +506,6 @@ def deploy_option(f):
 def setup_verbosity(ctx, param, value):
     if not value:
         return
-    import logging
-
-    loggers = ("pip",)
-    if value == 1:
-        for logger in loggers:
-            logging.getLogger(logger).setLevel(logging.INFO)
-    elif value == -1:
-        for logger in loggers:
-            logging.getLogger(logger).setLevel(logging.CRITICAL)
     ctx.ensure_object(State).project.s.PIPENV_VERBOSITY = value
 
 
@@ -573,7 +538,6 @@ def common_options(f):
     f = verbose_option(f)
     f = quiet_option(f)
     f = clear_option(f)
-    f = three_option(f)
     f = python_option(f)
     return f
 
@@ -582,11 +546,13 @@ def install_base_options(f):
     f = common_options(f)
     f = pre_option(f)
     f = keep_outdated_option(f)
+    f = extra_pip_args(f)
     return f
 
 
 def uninstall_options(f):
     f = install_base_options(f)
+    f = categories_option(f)
     f = uninstall_dev_option(f)
     f = skip_lock_option(f)
     f = editable_option(f)
@@ -597,16 +563,15 @@ def uninstall_options(f):
 def lock_options(f):
     f = install_base_options(f)
     f = lock_dev_option(f)
-    f = emit_requirements_flag(f)
-    f = emit_requirements_header_flag(f)
     f = dev_only_flag(f)
+    f = categories_option(f)
     return f
 
 
 def sync_options(f):
     f = install_base_options(f)
     f = install_dev_option(f)
-    f = sequential_option(f)
+    f = categories_option(f)
     return f
 
 
